package com.foreverwin.mesnac.common.service;

import java.util.List;
import java.util.Map;

public interface ReportDataService {
    /**
     * 查询质量检验任务
     *
     * @param paramMap
     * @return
     */
    List<Map<String, Object>> findInspectionTask(Map paramMap);

    /**
     * 查询质量检验任务明细
     *
     * @param paramMap
     * @return
     */
    List<Map<String, Object>> findInspectionTaskDetail(Map paramMap);

    /**
     * 设备、设备类型负荷率报表
     *
     * @param paramMap
     * @return
     */
    List<Map<String, Object>> findResourceOrResourceTypeLoadRateInfo(Map paramMap);

    /**
     * 设备维修数据统计报表
     *
     * @param paramMap
     * @return
     */
    List<Map<String, Object>> findResourceRepairDataStatInfo(Map paramMap);
    /**
     * 每日生产状态报表
     *
     * @param paramMap
     * @return
     */
    List<Map<String, Object>> findProductStateInfo(Map paramMap);

    List<Map<String, Object>> findWorkShopPassRate(Map paramMap);

    List<Map<String, Object>> findCheckUserPassRate(Map paramMap);


    List<Map<String, Object>> findUserPassRate(Map paramMap);

    List<Map<String, Object>> findInspectionDetailPassRate(Map paramMap);

    List<Map<String, Object>> findSectionPassRate(Map paramMap);

}
